@@ -11,17 +11,20 @@ class DictionaryService:
     def get_allergies(self, icd10_codes: list[str]) -> dict:
         query_params = {'icd10_code': icd10_codes}
         request_path = f"/allergies?{urlencode(query_params, doseq=True)}"
-        return self.service_provider.fetch_data(request_path).get('items')
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response.get('items')
 
     def get_medical_conditions(self, icd10_codes: list[str]) -> dict:
         query_params = {'icd10_code': icd10_codes}
         request_path = f"/medical_conditions?{urlencode(query_params, doseq=True)}"
-        return self.service_provider.fetch_data(request_path).get('items')
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response.get('items')
 
     def get_countries(self, iso_codes: list[str]) -> dict:
         query_params = {'iso_code': iso_codes}
         request_path = f"/countries?{urlencode(query_params, doseq=True)}"
-        return self.service_provider.fetch_data(request_path).get('items')
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response.get('items')
 
     def get_states(self,
                    iso_codes: list[str],
@@ -31,12 +34,14 @@ class DictionaryService:
         request_path = f"/states?{urlencode(query_params, doseq=True)}"
         if country_iso_code:
             request_path = f"/countries/{country_iso_code}/states?{urlencode(query_params, doseq=True)}"
-        return self.service_provider.fetch_data(request_path).get('items')
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response.get('items')
 
     def get_cities(self, city_ids: list[str]) -> dict:
         query_params = {'id': city_ids}
         request_path = f"/cities?{urlencode(query_params, doseq=True)}"
-        return self.service_provider.fetch_data(request_path).get('items')
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response.get('items')
 
     def get_tag_categories(
             self,
@@ -54,11 +59,13 @@ class DictionaryService:
 
         request_path = f"/tag_categories?{urlencode(query_params, doseq=True)}"
 
-        return self.service_provider.fetch_data(request_path)
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response
 
     def get_tag_category(self, tag_category_id: str) -> dict:
         request_path = f"/tag_categories/{tag_category_id}"
-        return self.service_provider.fetch_data(request_path)
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response
 
     def get_tags(self, search: str = None, is_active: bool = None) -> dict:
         query_params = {}
@@ -70,8 +77,10 @@ class DictionaryService:
 
         request_path = f"/tags?{urlencode(query_params, doseq=True)}"
 
-        return self.service_provider.fetch_data(request_path)
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response
 
     def get_tag(self, tag_id: str) -> dict:
         request_path = f"/tags/{tag_id}"
-        return self.service_provider.fetch_data(request_path)
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response
