@@ -1,8 +1,8 @@
 import uuid
 from typing import Union
+from fastapi import status
 
-from a360_services.utils.service_provider import ServiceProvider
-from a360_services.utils.services_list import Services
+from ..utils.service_provider import ServiceProvider
 
 
 class PracticeService:
@@ -25,7 +25,11 @@ class PracticeService:
         else:
             request_path = f"/experts/by_user_id/{str(user_id)}"
 
-        return self.service_provider.fetch_data(
-            service=Services.dict,
-            request_path=request_path
-        )
+        response, _ = self.service_provider.fetch_data(request_path)
+        return response
+
+    def is_practice_active(self, practice_id: uuid.UUID) -> bool:
+        request_path = f"/practices/{str(practice_id)}/is_active"
+        response, response_code = self.service_provider.fetch_data(
+            request_path)
+        return response_code == status.HTTP_200_OK
